@@ -75,9 +75,9 @@ def imicusfat_view(request):
             .reverse()[:30]
         )
 
-        char_1 = [char.character.character_name]
-
         if fat.count() > 0:
+            char_1 = [char.character.character_name]
+
             for f in fat:
                 char_1.append(f)
 
@@ -143,10 +143,11 @@ def stats(request, year=None):
     months = []
 
     for char in chars:
-        char_l = [char.character.character_name]
         char_fats = IFat.objects.filter(ifatlink__ifattime__year=year)
         char_stats = {}
 
+        char_has_fats = False
+
         for i in range(1, 13):
             char_fat_count = (
                 char_fats.filter(ifatlink__ifattime__month=i)
@@ -156,10 +157,13 @@ def stats(request, year=None):
 
             if char_fat_count > 0:
                 char_stats[str(i)] = char_fat_count
+                char_has_fats = True
 
-        char_l.append(char_stats)
-        char_l.append(char.character.character_id)
-        months.append(char_l)
+        if char_has_fats is True:
+            char_l = [char.character.character_name]
+            char_l.append(char_stats)
+            char_l.append(char.character.character_id)
+            months.append(char_l)
 
     # get users permissions
     permissions = get_user_permissions(request.user)
@@ -756,7 +760,9 @@ def links_data(request, year: int = None) -> JsonResponse:
         if fatlink.link_type:
             fatlink_type = fatlink.link_type.name
 
-        creator = fatlink.creator.profile.main_character.character_name
+        creator = fatlink.creator.username
+        if fatlink.creator.profile.main_character is not None:
+            creator = fatlink.creator.profile.main_character.character_name
         time = fatlink.ifattime
         fats_number = fatlink.number_of_fats
 
